==> jc-1.4.0.tar.gz: javax/swing/text/DefaultStyledDocument__24ElementBuffer.h <==
// public class javax.swing.text.DefaultStyledDocument$ElementBuffer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7f2e6e9dec5c8a7 javax_swing_text_DefaultStyledDocument__24ElementBuffer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_DefaultStyledDocument__24ElementBuffer_H_
#define _JC_javax_swing_text_DefaultStyledDocument__24ElementBuffer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_DefaultStyledDocument$object;
struct _jc_javax_swing_text_Element$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_refs	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_refs;
typedef struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_nonrefs	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$refs	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$refs;
typedef struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$nonrefs	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$nonrefs;
typedef struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$object	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$object;

typedef const struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vmethods	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vmethods;
typedef const struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtable	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtable;
typedef const struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtype	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$method$_init$a8bbcf777b645bf4(_jc_env *, struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$object *, struct _jc_javax_swing_text_DefaultStyledDocument$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$method$getRootElement$a9c2213251f32540(_jc_env *, struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$method_info$getRootElement$a9c2213251f32540;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vmethods {
	struct _jc_object	*(*getRootElement$a9c2213251f32540)(_jc_env *, struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$object *);
};

// Vtable
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vmethods	javax_swing_text_DefaultStyledDocument__24ElementBuffer;
};

// Vtype
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_refs {
	struct _jc_object	*root;
	struct _jc_javax_swing_text_DefaultStyledDocument$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$refs {
    _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_refs	javax_swing_text_DefaultStyledDocument__24ElementBuffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_nonrefs	javax_swing_text_DefaultStyledDocument__24ElementBuffer;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$object {
	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtype	*vtype;
	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtype _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultStyledDocument__24ElementBuffer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$class_object;

#endif	/* _JC_javax_swing_text_DefaultStyledDocument__24ElementBuffer_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/DefaultStyledDocument__24ElementBuffer.h <==
// public class javax.swing.text.DefaultStyledDocument$ElementBuffer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7f2e6e9dec5c8a7 javax_swing_text_DefaultStyledDocument__24ElementBuffer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_DefaultStyledDocument__24ElementBuffer_H_
#define _JC_javax_swing_text_DefaultStyledDocument__24ElementBuffer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_DefaultStyledDocument$object;
struct _jc_javax_swing_text_Element$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_refs	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_refs;
typedef struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_nonrefs	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$refs	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$refs;
typedef struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$nonrefs	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$nonrefs;
typedef struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$object	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$object;

typedef const struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vmethods	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vmethods;
typedef const struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtable	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtable;
typedef const struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtype	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$method$_init$a8bbcf777b645bf4(_jc_env *, struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$object *, struct _jc_javax_swing_text_DefaultStyledDocument$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$method$getRootElement$a9c2213251f32540(_jc_env *, struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$method_info$getRootElement$a9c2213251f32540;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vmethods {
	struct _jc_object	*(*getRootElement$a9c2213251f32540)(_jc_env *, struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vmethods	javax_swing_text_DefaultStyledDocument__24ElementBuffer;
};

// Vtype
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_refs {
	struct _jc_object	*root;
	struct _jc_javax_swing_text_DefaultStyledDocument$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$refs {
    _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_refs	javax_swing_text_DefaultStyledDocument__24ElementBuffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$sub_nonrefs	javax_swing_text_DefaultStyledDocument__24ElementBuffer;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$object {
	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtype	*vtype;
	_jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$vtype _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultStyledDocument__24ElementBuffer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultStyledDocument__24ElementBuffer$class_object;

#endif	/* _JC_javax_swing_text_DefaultStyledDocument__24ElementBuffer_H_ */
